@@ -6,8 +6,8 @@
 ;; Author: Campbell Barton <ideasman42@gmail.com>
 
 ;; URL: https://codeberg.org/ideasman42/emacs-mono-complete
-;; Package-Version: 20251031.6
-;; Package-Revision: 4da2cf423305
+;; Package-Version: 20251126.1132
+;; Package-Revision: 71d46dc015cc
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -242,7 +242,7 @@ using `default-directory' as a fallback."
     ;; Interactive only, when non-interactive,
     ;; the macros called here will be in-lined
     ;; and there is no need to perform any functionality in that case.
-    (not (or executing-kbd-macro noninteractive)))
+    (null (or executing-kbd-macro noninteractive)))
    (t
     t)))
 
@@ -669,7 +669,7 @@ Argument STATE is the result of `mono-complete--preview-state-from-overlay'."
           (setq do-clear-timer nil))))
 
       (when (eq do-reset :unset)
-        (setq do-reset (not (mono-complete--is-mono-complete-command this-command))))
+        (setq do-reset (null (mono-complete--is-mono-complete-command this-command))))
 
       (when do-clear-timer
         (when (timerp mono-complete--preview-timer)
